==> puppetdb_4.4.1.orig.tar.gz: puppetdb-4.4.1/puppet/spec/spec_helper.rb <==
dir = File.expand_path(File.dirname(__FILE__))
$LOAD_PATH.unshift File.join(dir, "../lib")
# Maybe puppetlabs_spec_helper is in a directory next to puppetdb. If not, we
# don't fail any worse than we already would.
$LOAD_PATH.push File.join(dir, "../../../puppetlabs_spec_helper")

require 'rspec'
require 'rspec/expectations'
require 'puppetlabs_spec_helper/puppet_spec_helper'
require 'tmpdir'
require 'fileutils'
require 'puppet'
require 'puppet/util/puppetdb'
require 'puppet/util/log'


# A mock class for an http_instance so that the `multi_arity_get` function
# will work in tests.
class HttpClientTest
  def get(path, headers, options)
  end
end

def create_environmentdir(environment)
  envdir = File.join(Puppet[:environmentpath], environment)
  if not Dir.exists?(envdir)
    Dir.mkdir(envdir)
  end
end

def extract_producer_timestamp(command)
  DateTime.parse(command["producer_timestamp"]).to_time.to_i
end

def assert_command_req(expected_payload, actual_payload)
  req = JSON.parse(actual_payload)
  actual_producer_timestamp = extract_producer_timestamp(req)
  req.delete("producer_timestamp")
  req == expected_payload &&
    actual_producer_timestamp <= Time.now.to_i
end

RSpec.configure do |config|

  config.before :each do
    @logs = []
    Puppet::Util::Log.level = :info
    Puppet::Util::Log.newdestination(Puppet::Test::LogCollector.new(@logs))

    def test_logs
      @logs.map(&:message)
    end

  end

  config.expect_with :rspec do |c|
    c.syntax = [:should, :expect]
  end

end

==> puppetdb_6.2.0.orig.tar.gz: puppetdb-6.2.0/puppet/spec/spec_helper.rb <==
dir = File.expand_path(File.dirname(__FILE__))
$LOAD_PATH.unshift File.join(dir, "../lib")
# Maybe puppetlabs_spec_helper is in a directory next to puppetdb. If not, we
# don't fail any worse than we already would.
$LOAD_PATH.push File.join(dir, "../../../puppetlabs_spec_helper")

require 'cgi'
require 'rspec'
require 'rspec/expectations'
require 'puppetlabs_spec_helper/puppet_spec_helper'
require 'tmpdir'
require 'fileutils'
require 'puppet'
require 'puppet/util/puppetdb'
require 'puppet/util/log'


def create_environmentdir(environment)
  envdir = File.join(Puppet[:environmentpath], environment)
  if not Dir.exists?(envdir)
    Dir.mkdir(envdir)
  end
end

def extract_producer_timestamp(command)
  DateTime.parse(command["producer_timestamp"]).to_time.to_i
end

def assert_command_req(expected_payload, actual_payload)
  req = JSON.parse(actual_payload)
  actual_producer_timestamp = extract_producer_timestamp(req)
  req.delete("producer_timestamp")
  req == expected_payload &&
    actual_producer_timestamp <= Time.now.to_i
end

def assert_valid_producer_ts(path)
  _, param_str = path.split "?"
  params = CGI::parse(param_str)
  return false if params["producer-timestamp"].size != 1
  Time.iso8601(params["producer-timestamp"].first)
end

RSpec.configure do |config|

  config.before :each do
    @logs = []
    Puppet::Util::Log.level = :info
    Puppet::Util::Log.newdestination(Puppet::Test::LogCollector.new(@logs))

    def test_logs
      @logs.map(&:message)
    end

  end

  config.expect_with :rspec do |c|
    c.syntax = [:should, :expect]
  end

end
